==> dwarfg_install_1.2.0.tgz: dwarfg_install/appdir/web/gui/src/Form/Device/MonitoringGroupType.php <==
<?php

namespace App\Form\Device;

use App\Entity\MonitoringGroup\MonitoringGroup;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\ChoiceType;
use Symfony\Component\Form\Extension\Core\Type\SubmitType;
use Symfony\Component\Form\FormBuilderInterface;

class MonitoringGroupType extends AbstractType
{

    /**
     * @param FormBuilderInterface $builder
     * @param array $options
     */
    public function buildForm(FormBuilderInterface $builder, array $options): void
	{

        /** @var MonitoringGroup $deviceMonitoringGroups */
        $deviceMonitoringGroups = $options['data']['deviceMonitoringGroups'];
        $monitoringGroups = $options['data']['monitoringGroups'];

        $selectedItems = [];

        foreach ($deviceMonitoringGroups as $item) {
            $selectedItems[] = $item->getMonitoringGroup()->getId();
        }

        $choices = [];

        foreach ($monitoringGroups as $item) {

            $choices[$item->getName()] = $item->getId();

        }

        $builder
            ->add('monitoringGroups', ChoiceType::class, [
                'choices' => $choices,
                'placeholder' => 'Select a Monitoring Group',
                'multiple' => true,
                'required' => false,
                'data' => $selectedItems,
            ])

            ->add('save', SubmitType::class, [
				'label' => '<i class="fas fa fa-layer-group"></i> Set ',
				'label_html' => true,
                'block_prefix' => 'modal_footer'
			])
        ;

    }

}

==> dwarfg_install_1.9.0.tgz: dwarfg_install/appdir/web/gui/src/Form/Device/MonitoringGroupType.php <==
<?php

namespace App\Form\Device;

use App\Entity\MonitoringGroup\MonitoringGroup;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\ChoiceType;
use Symfony\Component\Form\Extension\Core\Type\SubmitType;
use Symfony\Component\Form\FormBuilderInterface;

class MonitoringGroupType extends AbstractType
{

    /**
     * @param FormBuilderInterface $builder
     * @param array $options
     */
    public function buildForm(FormBuilderInterface $builder, array $options): void
	{

        /** @var MonitoringGroup $deviceMonitoringGroups */
        $deviceMonitoringGroups = $options['data']['deviceMonitoringGroups'];
        $monitoringGroups = $options['data']['monitoringGroups'];

        $selectedItems = [];

        foreach ($deviceMonitoringGroups as $item) {
            $selectedItems[] = $item->getMonitoringGroup()->getId();
        }

        $choices = [];

        foreach ($monitoringGroups as $item) {

            $choices[$item->getName()] = $item->getId();

        }

        $builder
            ->add('monitoringGroups', ChoiceType::class, [
                'choices' => $choices,
                'placeholder' => 'Select a Monitoring Group',
                'multiple' => true,
                'required' => false,
                'data' => $selectedItems,
            ])

            ->add('save', SubmitType::class, [
				'label' => 'Set ',
				'label_html' => true,
				'icon' => 'fas fa fa-layer-group',
                'block_prefix' => 'modal_footer'
			])
        ;

    }

}
